==> pointpos_api-0.2.0.tar.gz: test/customer_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Customer
void main() {
  var instance = new Customer();

  group('test Customer', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String email (default value: null)
    test('to test the property `email`', () async {
      // TODO
    });

    // String phone (default value: null)
    test('to test the property `phone`', () async {
      // TODO
    });

    // String birthday (default value: null)
    test('to test the property `birthday`', () async {
      // TODO
    });

    // String gender (default value: null)
    test('to test the property `gender`', () async {
      // TODO
    });

    // String address (default value: null)
    test('to test the property `address`', () async {
      // TODO
    });

    // String city (default value: null)
    test('to test the property `city`', () async {
      // TODO
    });

    // String state (default value: null)
    test('to test the property `state`', () async {
      // TODO
    });

    // String zipCode (default value: null)
    test('to test the property `zipCode`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/customer_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Customer
void main() {
  var instance = new Customer();

  group('test Customer', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String email (default value: null)
    test('to test the property `email`', () async {
      // TODO
    });

    // String phone (default value: null)
    test('to test the property `phone`', () async {
      // TODO
    });

    // String birthday (default value: null)
    test('to test the property `birthday`', () async {
      // TODO
    });

    // String gender (default value: null)
    test('to test the property `gender`', () async {
      // TODO
    });

    // String address (default value: null)
    test('to test the property `address`', () async {
      // TODO
    });

    // String city (default value: null)
    test('to test the property `city`', () async {
      // TODO
    });

    // String state (default value: null)
    test('to test the property `state`', () async {
      // TODO
    });

    // String zipCode (default value: null)
    test('to test the property `zipCode`', () async {
      // TODO
    });

    // DateTime lastVisit (default value: null)
    test('to test the property `lastVisit`', () async {
      // TODO
    });

    // int totalVisit (default value: null)
    test('to test the property `totalVisit`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
